@@ -1199,7 +1199,7 @@ void Dolphin::setupActions()
                                         actionCollection(), "delete");
     deleteAction->setIcon("edit-delete");
 
-    new TDEAction(i18n("Propert&ies"), "Alt+Return",
+    new TDEAction(i18n("Propert&ies"), "edit", "Alt+Return",
                      TQT_TQOBJECT(this), TQT_SLOT(properties()),
                      actionCollection(), "properties");
 
