@@ -21,15 +21,15 @@
 #include "dolphiniconsview.h"
 #include <tqpainter.h>
 #include <kiconeffect.h>
-#include <kapplication.h>
+#include <tdeapplication.h>
 #include <tqobjectlist.h>
-#include <kglobalsettings.h>
+#include <tdeglobalsettings.h>
 #include <kurldrag.h>
 #include <tqclipboard.h>
 #include <assert.h>
-#include <kaction.h>
+#include <tdeaction.h>
 #include <kstdaction.h>
-#include <kfileitem.h>
+#include <tdefileitem.h>
 
 #include "dolphinview.h"
 #include "viewproperties.h"
@@ -45,7 +45,7 @@ DolphinIconsView::DolphinIconsView(DolphinView* parent, LayoutMode layoutMode) :
     m_dolphinView(parent)
 {
     setAcceptDrops(true);
-    setMode(KIconView::Execute);
+    setMode(TDEIconView::Execute);
     setSelectionMode(KFile::Extended);
     Dolphin& dolphin = Dolphin::mainWin();
 
@@ -71,11 +71,11 @@ DolphinIconsView::DolphinIconsView(DolphinView* parent, LayoutMode layoutMode) :
     // KFileIconView creates two actions for zooming, which are directly connected to the
     // slots KFileIconView::zoomIn() and KFileIconView::zoomOut(). As this behavior is not
     // wanted and the slots are not virtual, the actions are disabled here.
-    KAction* zoomInAction = actionCollection()->action("zoomIn");
+    TDEAction* zoomInAction = actionCollection()->action("zoomIn");
     assert(zoomInAction != 0);
     zoomInAction->setEnabled(false);
 
-    KAction* zoomOutAction = actionCollection()->action("zoomOut");
+    TDEAction* zoomOutAction = actionCollection()->action("zoomOut");
     assert(zoomOutAction != 0);
     zoomOutAction->setEnabled(false);
 
@@ -207,13 +207,13 @@ bool DolphinIconsView::isZoomInPossible() const
 {
     DolphinIconsViewSettings* settings = DolphinSettings::instance().iconsView(m_layoutMode);
     const int size = (m_layoutMode == Icons) ? settings->iconSize() : settings->previewSize();
-    return size < KIcon::SizeEnormous;
+    return size < TDEIcon::SizeEnormous;
 }
 
 bool DolphinIconsView::isZoomOutPossible() const
 {
     DolphinIconsViewSettings* settings = DolphinSettings::instance().iconsView(m_layoutMode);
-    return settings->iconSize() > KIcon::SizeSmall;
+    return settings->iconSize() > TDEIcon::SizeSmall;
 }
 
 void DolphinIconsView::arrangeItemsInGrid( bool updated )
@@ -309,7 +309,7 @@ TQDragObject* DolphinIconsView::dragObject()
 
     TQPixmap pixmap;
     if(urls.count() > 1) {
-        pixmap = DesktopIcon("kmultiple", iconSize());
+        pixmap = DesktopIcon("application-vnd.tde.tdemultiple", iconSize());
     }
     else {
         KFileIconViewItem* item = static_cast<KFileIconViewItem*>(currentItem());
@@ -473,11 +473,11 @@ int DolphinIconsView::increasedIconSize(int size) const
 {
     int incSize = 0;
     switch (size) {
-        case KIcon::SizeSmall:       incSize = KIcon::SizeSmallMedium; break;
-        case KIcon::SizeSmallMedium: incSize = KIcon::SizeMedium; break;
-        case KIcon::SizeMedium:      incSize = KIcon::SizeLarge; break;
-        case KIcon::SizeLarge:       incSize = KIcon::SizeHuge; break;
-        case KIcon::SizeHuge:        incSize = KIcon::SizeEnormous; break;
+        case TDEIcon::SizeSmall:       incSize = TDEIcon::SizeSmallMedium; break;
+        case TDEIcon::SizeSmallMedium: incSize = TDEIcon::SizeMedium; break;
+        case TDEIcon::SizeMedium:      incSize = TDEIcon::SizeLarge; break;
+        case TDEIcon::SizeLarge:       incSize = TDEIcon::SizeHuge; break;
+        case TDEIcon::SizeHuge:        incSize = TDEIcon::SizeEnormous; break;
         default: assert(false); break;
     }
     return incSize;
@@ -487,11 +487,11 @@ int DolphinIconsView::decreasedIconSize(int size) const
 {
     int decSize = 0;
     switch (size) {
-        case KIcon::SizeSmallMedium: decSize = KIcon::SizeSmall; break;
-        case KIcon::SizeMedium: decSize = KIcon::SizeSmallMedium; break;
-        case KIcon::SizeLarge: decSize = KIcon::SizeMedium; break;
-        case KIcon::SizeHuge: decSize = KIcon::SizeLarge; break;
-        case KIcon::SizeEnormous: decSize = KIcon::SizeHuge; break;
+        case TDEIcon::SizeSmallMedium: decSize = TDEIcon::SizeSmall; break;
+        case TDEIcon::SizeMedium: decSize = TDEIcon::SizeSmallMedium; break;
+        case TDEIcon::SizeLarge: decSize = TDEIcon::SizeMedium; break;
+        case TDEIcon::SizeHuge: decSize = TDEIcon::SizeLarge; break;
+        case TDEIcon::SizeEnormous: decSize = TDEIcon::SizeHuge; break;
         default: assert(false); break;
     }
     return decSize;
